# ImgWorks

A simple CLI tool to work with images, it helps you convert between formats (I personally dislike .webp and .heic so much when working in desktop) as well as resize images with a single command.

## Installation

```bash
pip install imgworks
```
## Usage

It has several commands, you can learn more about them by using the `--help` flag.

 - Resize images: `resize`
 - Convert images: `heic2jpg`, `webp2jpg`, `heic2png` and `webp2png`
 